@@ -1,10 +1,8 @@
-# Copyright (c) 2008 Simplistix Ltd
-# See license.txt for license details.
+from unittest import TestCase
 
-from unittest import TestCase, TestSuite, makeSuite
+from types import GeneratorType
 
 from testfixtures import generator
-from types import GeneratorType
 
 
 class TestG(TestCase):
